@@ -34,7 +34,7 @@ class Release(setuptools.Command):
         self.version = self.distribution.get_version()
         pypi = xmlrpclib.ServerProxy("http://pypi.python.org/pypi")
         print "current version: {0}".format(self.version)
-        releases = pypi.package_releases(self.name) # show visible only
+        releases = pypi.package_releases(self.name) # shows visible only
         print "Pypi releases: {0}".format(", ".join(releases))
 
     def check(self):
@@ -54,7 +54,6 @@ class Release(setuptools.Command):
             if not "(200)" in last_line:
                 raise RuntimeError(last_line)
 
-
             response = setup("sdist", "upload")
             print response
             last_line = str(response).splitlines()[-1]
